Learn R Programming

NCA (version 3.0.3)

line.colors: a set defining the line colors for the plots

Description

Set before calling nca_output > line.colors['ce_fdh'] <- 'blue' Reset one line color by setting it to NULL > line.colors['ce_fdh'] <- NULL Reset all line colors by setting line.colors to NULL > line.colors <- NULL

Arguments

Format

This is a list with line colors for each ceiling technique

ols 'green' lh 'red3'
cols 'darkgreen' qr 'blue'
ce_vrs 'orchid4' cr_vrs 'violet'
ce_fdh 'red' cr_fdh 'orange'