Learn R Programming

NCA (version 3.0.3)

line.types: a set defining the line types for the plots

Description

Set before calling nca_output > line.types['ce_fdh'] <- 1 Reset one line type by setting it to NULL > line.types['ce_fdh'] <- NULL Reset all line types by setting line.types to NULL > line.types <- NULL

Arguments

Format

This is a list with line types for each ceiling technique

ols 1 lh 2
cols 3 qr 4
ce_vrs 5 cr_vrs 1
ce_fdh 6 cr_fdh 1