Learn R Programming

NCA (version 2.0)

line.width: parameter defining the width of the lines in the plots

Description

This will be used for the lwd parameter of the plot, default is 1.5. Set before calling nca_output > line.width <- 5

Arguments