Learn R Programming

NCA (version 5.0.0)

nca.example: NCA example data with 2 conditions and 1 output

Description

This data set has Individualism and Risk taking as conditions, and Innovation performance as the output for 28 countries.

Usage

data(nca.example)

Arguments

Format

A matrix containing 28 observations, incl. headers and row names.