| nca_power | R Documentation |
Function to evaluate power, test if a sample size is large enough to detect necessity.
nca_power(n = c(20, 50, 100), effect = 0.10, slope = 1, ceiling = "ce_fdh",
corner = 1, p = 0.05, distribution.x = "uniform", distribution.y = "uniform",
rep = 100, test.rep = 200)
n |
Number of datapoints to generate, either an integer or a vector of integers. |
effect |
Effect size of the generated datasets (single value or vector of values). |
slope |
Slope of the line (single value or vector of values). |
ceiling |
Ceiling technique to use for this analysis (single value or vector of values). |
corner |
Integer, indicating the corner to analyze, see nca_analysis. |
p |
Significance level. |
distribution.x |
Distribution type(s) for X, "uniform" (default) or "normal" (single value or vector of values). |
distribution.y |
Distribution type(s) for Y, "uniform" (default) or "normal" (single value or vector of values). |
rep |
Number of analyses done per iteration. |
test.rep |
Number of resamples in the statistical approximate permutation test.
For test.rep = 0 no statistical test is performed. See |
# Simple example
## Not run: results <- nca_power()
print(results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.