Set before calling nca_output > line.types["ce_fdh"] <- 1 Reset one line type by setting it to NULL > line.types["ce_fdh"] <- NULL Reset all line types by setting line.types to NULL > line.types <- NULL
This is a list with line types for each ceiling technique
| ols | 1 | cols | 3 | |
| lh | 2 | qr | 4 | |
| ce_vrs | 5 | cr_vrs | 1 | |
| ce_fdh | 6 | cr_fdh | 1 |