Learn R Programming

NCA (version 2.0)

nca_output: display the result of the NCA analysis

Description

Show the plots, NCA summaries and bottlenecks of a NCA analysis.

Usage

nca_output(model, plots=FALSE, bottlenecks=FALSE, summaries=TRUE,
                  pdf=FALSE, path=NULL)

Arguments

model

the output of the nca or nca_analysis commands

plots

if true show the plot(s)

bottlenecks

if true show the bottleneck table(s)

summaries

if true show the summaries

pdf

if true export to pdf

path

optional path for the output file(s)

Examples

Run this code
# NOT RUN {
  # Use the result of the nca command :
  data(nca.example)
  data <- nca.example
  model <- nca_analysis(data, c(1, 2), 3)

  # This shows the summaries in the console
  nca_output(model)

  # Suppress the summaries and display the plots
  nca_output(model, plots=TRUE, summaries=FALSE)

  # Suppress the summaries and display the bottlenecks
  nca_output(model, bottlenecks=TRUE, summaries=FALSE)

  # Show all three
  nca_output(model, plots=TRUE, bottlenecks=TRUE)

  # Export to PDF, the plots and summaries each to a file per independent variable
  # All the bottlenecks will exported to a single file
  nca_output(model, plots=TRUE, bottlenecks=TRUE, pdf=TRUE)

  # Use the path option to export to an existing directory
  outdir <- "/tmp" 
# }
# NOT RUN {
  nca_output(model, plots=TRUE, pdf=TRUE, path=outdir)
# }

Run the code above in your browser using DataLab