Number of datapoints to generate, either an integer or a vector of integers.
effect
Effect size of the generated datasets (single value or vector of values).
slope
Slope of the line (single value or vector of values).
ceiling
Ceiling technique to use for this analysis (single value or vector of values).
corner
Integer, indicating the corner to analyze, see nca_analysis.
p
Significance level.
distribution.x
Distribution type(s) for X, "uniform" (default) or "normal" (single value or vector of values).
distribution.y
Distribution type(s) for Y, "uniform" (default) or "normal" (single value or vector of values).
rep
Number of analyses done per iteration.
test.rep
Number of resamples in the statistical approximate permutation test.
For test.rep = 0 no statistical test is performed. See nca_analysis
for reproducible outputs.