# Simple example, showing a normal plot with the power as a function of the sample size
# A line for each effect size will be shown
if (FALSE) results <- nca_power(effect = c(.1, .2, .3))
results <- nca_power(effect = c(.1, .2, .3), rep=2, test.rep = 1)
nca_powerplot(results)
# This example shows the power for different ceiling lines
if (FALSE) results <- nca_power(ceiling = c("ce_fdh", "cr_fdh"))
results <- nca_power(ceiling = c("ce_fdh", "cr_fdh"), rep=2, test.rep = 1)
powerplot <- nca_powerplot(results, line.variable='ceiling', line.name='Ceiling')
Run the code above in your browser using DataLab